%define lib_name_orig lib%{name}
%define major 5
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d
%define staticname %mklibname %{name} -d -s

%define hyphvers %(echo %{version}|sed -e 's/\\./\\-/g')

Summary: Utilities for lm_sensors
Name:    lm_sensors
Epoch:   1
Version: 3.6.0
Release: %mkrel 5
License: GPLv2+
Group:   System/Kernel and hardware
URL:     https://github.com/lm-sensors/lm-sensors
Source0: https://github.com/lm-sensors/lm-sensors/archive/V%{hyphvers}/lm-sensors-%{hyphvers}.tar.gz
Source3: sensord.service
Source4: lm_sensors.sysconfig
Patch1:  0001-egrep-is-obsolete-replacing-with-grep-E.patch
BuildRequires: bison
BuildRequires: chrpath
BuildRequires: flex
BuildRequires: pkgconfig(librrd)
BuildRequires: libsysfs-devel
Requires(post): rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

%description
This package contains a collection of user space tools for general SMBus
access and hardware monitoring. SMBus, also known as System Management Bus,
is a protocol for communicating through a I2C ('I squared C') bus. Many modern
mainboards have a System Management Bus. There are a lot of devices which can
be connected to a SMBus; the most notable are modern memory chips with EEPROM
memories and chips for hardware monitoring.

Most modern mainboards incorporate some form of hardware monitoring chips.
These chips read things like chip temperatures, fan rotation speeds and
voltage levels. There are quite a few different chips which can be used
by mainboard builders for approximately the same results.

%package -n %{libname}
Summary: Libraries needed for lm_sensors
Group:   System/Libraries

%description -n	%{libname}
Libraries to access lm_sensors internal data.

%package -n %{develname}
Summary: Development libraries and header files for lm_sensors
Group:   Development/C
Requires(pre): %{libname} = %{epoch}:%{version}-%{release}
Requires(postun): %{libname} = %{epoch}:%{version}-%{release}
Requires: %{libname} = %{epoch}:%{version}-%{release}
Provides: lib%{name}-devel = %{epoch}:%{version}-%{release}
Provides: %{name}-devel = %{epoch}:%{version}-%{release}
Obsoletes: %{name}-devel < %{epoch}:%{version}-%{release}

%description -n %{develname}
Development libraries and header files for lm_sensors.

You might want to use this package while building applications that might
take advantage of lm_sensors if found.

%package -n %{staticname}
Summary: Static libraries for lm_sensors
Group:   Development/C
Requires(pre): %{develname} = %{epoch}:%{version}-%{release}
Requires(postun): %{develname} = %{epoch}:%{version}-%{release}
Provides: lib%{name}-static-devel = %{epoch}:%{version}-%{release}
Obsoletes: %{name}-static-devel < %{epoch}:%{version}-%{release}

%description -n %{staticname}
This package contains static libraries for lm_sensors.

%prep
%autosetup -p1 -n lm-sensors-%{hyphvers}

# fix runstatedir
sed -i -e 's,/var/run,%{_rundir},g' $(grep -rl /var/run)

%build
%set_build_flags
%define _MAKE_DEFS COMPILE_KERNEL=0 WARN=1 PREFIX=%{_prefix} ETCDIR=%{_sysconfdir} MANDIR=%{_mandir} PROG_EXTRA:=sensord LIBDIR=%{_libdir}
%define MAKE_DEFS %{_MAKE_DEFS}

# (tpg) get rid of custom ldflags, rpath
sed -i -e 's/EXLDFLAGS :=.*/EXLDFLAGS :=$(LDFLAGS)/g' Makefile

%make_build %{MAKE_DEFS} user

%install
%define MAKE_DEFS %{_MAKE_DEFS}

%make_install %{MAKE_DEFS} user_install

%{__mkdir_p} %{buildroot}%{_initrddir}
%{_bindir}/chrpath -d %{buildroot}%{_sbindir}/sensord
%{_bindir}/chrpath -d %{buildroot}%{_bindir}/sensors
%ifnarch ppc %arm %mips aarch64
%{_bindir}/chrpath -d %{buildroot}%{_sbindir}/isadump
%{_bindir}/chrpath -d %{buildroot}%{_sbindir}/isaset
%endif

%{__cat} > README.urpmi << EOF
* To use this package, you'll have to launch "sensors-detect" as root, and answer a few questions.
  No need to modify startup files as shown at the end, all will be done.
EOF

install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 %{SOURCE3} %{buildroot}%{_unitdir}/sensord.service
install -m 644 prog/init/lm_sensors.service %{buildroot}%{_unitdir}

# placeholder
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -p -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sysconfig/lm_sensors

%post
MIGRATE=
[ ! -f %{_sysconfdir}/systemd/system/multi-user.target.wants/lm_sensors.service ] && MIGRATE=yes
%_post_service lm_sensors
%_post_service sensord
# (cg) Deal with a quirk of packaging... enable sensord if lm_sensors is enabled
if [ "$MIGRATE" = "yes" -a -f %{_sysconfdir}/systemd/system/multi-user.target.wants/lm_sensors.service ]; then
  ln -sf %{_unitdir}/sensord.service %{_sysconfdir}/systemd/system/multi-user.target.wants/sensord.service
fi

%preun
%_preun_service lm_sensors
%_preun_service sensord

%files
%doc CHANGES CONTRIBUTORS README doc README.urpmi
%config(noreplace) %{_sysconfdir}/sensors3.conf
%config(noreplace) %{_sysconfdir}/sysconfig/lm_sensors
%{_unitdir}/sensord.service
%{_unitdir}/lm_sensors.service
%{_bindir}/sensors
%{_bindir}/sensors-conf-convert
%ifnarch ppc %arm %mips aarch64
%{_sbindir}/isadump
%{_sbindir}/isaset
%endif
%{_sbindir}/sensors-detect
%{_sbindir}/sensord
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%{_sbindir}/fancontrol
%{_sbindir}/pwmconfig

%files -n %{libname}
%{_libdir}/libsensors.so.%{major}
%{_libdir}/libsensors.so.%{major}.*

%files -n %{develname}
%{_libdir}/libsensors.so
%dir %{_includedir}/sensors
%{_includedir}/sensors/*
%{_mandir}/man3/*

%files -n %{staticname}
%{_libdir}/libsensors.a


%changelog
* Sat Jun 28 2025 umeabot <umeabot> 1:3.6.0-5.mga10
+ Revision: 2218234
- Mageia 10 Mass Rebuild

* Thu May 04 2023 daviddavid <daviddavid> 1:3.6.0-4.mga9
+ Revision: 1955743
- add patch to use `grep -E` instead of deprecated `egrep`

* Fri Apr 01 2022 umeabot <umeabot> 1:3.6.0-3.mga9
+ Revision: 1838453
- Mageia 9 Mass Rebuild

* Sun Feb 16 2020 umeabot <umeabot> 1:3.6.0-2.mga8
+ Revision: 1536548
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Fri Oct 18 2019 daviddavid <daviddavid> 1:3.6.0-1.mga8
+ Revision: 1454468
- new version: 3.6.0

* Tue Jul 23 2019 tmb <tmb> 1:3.5.0-3.mga8
+ Revision: 1423641
- fix applying patch
- update post 3.5.0 changes from git

* Sat Feb 16 2019 wally <wally> 1:3.5.0-2.mga7
+ Revision: 1367518
- store PID files to /run instead of /var/run

* Sat Dec 29 2018 luigiwalser <luigiwalser> 1:3.5.0-1.mga7
+ Revision: 1346534
- library major is now 5
- 3.5.0

* Tue Oct 02 2018 semiletov <semiletov> 1:3.4.0.git20181002-1.mga7
+ Revision: 1315749
- update to upstream

* Sun Sep 23 2018 umeabot <umeabot> 1:3.4.0.git20180318-4.mga7
+ Revision: 1299334
- Mageia 7 Mass Rebuild

* Sun Jul 29 2018 cjw <cjw> 1:3.4.0.git20180318-3.mga7
+ Revision: 1245879
- remove source tarball installed as init script

* Sun Jun 03 2018 wally <wally> 1:3.4.0.git20180318-2.mga7
+ Revision: 1234055
- fix build on aarch64

* Thu Mar 22 2018 tmb <tmb> 1:3.4.0.git20180318-1.mga7
+ Revision: 1211181
- update to 2018-03-18 snapshot

* Tue Dec 26 2017 semiletov <semiletov> 1:3.4.0.git20171224-1.mga7
+ Revision: 1185450
- switch from release to more fixed and current snapshot, URL changed as the main site is down

* Thu Aug 24 2017 ovitters <ovitters> 1:3.4.0-3.mga7
+ Revision: 1145035
+ rebuild (emptylog)

* Fri May 06 2016 luigiwalser <luigiwalser> 1:3.4.0-3.mga6
+ Revision: 1010063
- rebuild for rrdtool

* Fri Feb 12 2016 umeabot <umeabot> 1:3.4.0-2.mga6
+ Revision: 956041
- Mageia 6 Mass Rebuild

* Thu Aug 13 2015 daviddavid <daviddavid> 1:3.4.0-1.mga6
+ Revision: 864173
- new version: 3.4.0
- remove no more needed explicit requires and provides on lib(64)lm_sensors4

* Wed Oct 15 2014 umeabot <umeabot> 1:3.3.5-3.mga5
+ Revision: 746246
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:3.3.5-2.mga5
+ Revision: 681971
- Mageia 5 Mass Rebuild

* Tue Feb 04 2014 dams <dams> 1:3.3.5-1.mga5
+ Revision: 580815
- new version 3.3.5

* Sat Oct 19 2013 umeabot <umeabot> 1:3.3.4-2.mga4
+ Revision: 526391
- Mageia 4 Mass Rebuild

* Tue Jun 04 2013 dams <dams> 1:3.3.4-1.mga4
+ Revision: 436860
- new version 3.3.4

* Sun Feb 03 2013 sander85 <sander85> 1:3.3.3-3.mga3
+ Revision: 394260
- Add placeholder for /etc/sysconfig/lm_sensors (like Fedora does)

* Sat Jan 12 2013 umeabot <umeabot> 1:3.3.3-2.mga3
+ Revision: 358915
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Nov 07 2012 fwang <fwang> 1:3.3.3-1.mga3
+ Revision: 315723
- new version 3.3.3

* Sat Apr 28 2012 tmb <tmb> 1:3.3.2-6.mga2
+ Revision: 233773
- Require rpm-helper >= 0.24.8-1 for systemd support

* Sun Apr 22 2012 colin <colin> 1:3.3.2-5.mga2
+ Revision: 232603
- Fix systemd unit migration
- Use included sensors-detect rather than outdated backport

* Sat Apr 21 2012 colin <colin> 1:3.3.2-4.mga2
+ Revision: 232339
- Neater masking of sysvinit script under systemd.

* Sat Apr 21 2012 colin <colin> 1:3.3.2-3.mga2
+ Revision: 232323
- Fix systemd unit and migration

* Wed Apr 18 2012 guillomovitch <guillomovitch> 1:3.3.2-2.mga2
+ Revision: 231321
- spec cleanup
- systemd support

* Thu Apr 05 2012 tmb <tmb> 1:3.3.2-1.mga2
+ Revision: 228648
- update to 3.3.2 (supports new kernels)

* Sat Mar 03 2012 malo <malo> 1:3.3.1-2.mga2
+ Revision: 217603
- added up-to-date sensor-detect for newer hardware (mga#4095)
+ kharec <kharec>
- try to fix rpmlint's warning on lsb-keywords
- new release that makes sensors-detect up-to-date with new devices.

* Sun Jun 19 2011 kharec <kharec> 1:3.3.0-1.mga2
+ Revision: 109644
- new version 3.3.0

* Fri Jan 14 2011 dmorgan <dmorgan> 1:3.2.0-1.mga1
+ Revision: 17434
- Get rid of mdv macros
- imported package lm_sensors


* Tue Oct 12 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.2.0-1mdv2011.0
+ Revision: 585211
- new version

* Thu Feb 25 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1:3.1.2-3mdv2010.1
+ Revision: 510828
- correct requires for static subpackage

* Wed Feb 24 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1:3.1.2-2mdv2010.1
+ Revision: 510762
- use new devel library policy

* Thu Feb 04 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.1.2-1mdv2010.1
+ Revision: 500980
- new version

* Sun Sep 27 2009 Olivier Blin <oblin@mandriva.com> 1:3.1.1-2mdv2010.0
+ Revision: 450119
- do not use kernel-source includes (from Arnaud Patard)
- do not list isa tools on mips & arm, they don't have it
  (from Arnaud Patard)
- drop kernel_source dep: used only if building modules, which is not
  our case (from Arnaud Patard)

* Sat Aug 29 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.1.1-1mdv2010.0
+ Revision: 422155
- new version
- spec cleanup

* Tue Dec 30 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.10.8-1mdv2009.1
+ Revision: 321505
- fix url
- new license policy
- protect major in file list
- compile with %%optflags and %%ldflags
- spec file clean
- update to new version 2.10.8

* Thu Sep 18 2008 Frederic Crozat <fcrozat@mandriva.com> 1:2.10.7-1mdv2009.0
+ Revision: 285719
- Release 2.10.7, fix sensors detection with kernel >= 2.6.26 (Mdv bug #43986)

* Tue Jun 17 2008 Oden Eriksson <oeriksson@mandriva.com> 1:2.10.5-4mdv2009.0
+ Revision: 222465
- rebuilt against new rrdtool-devel

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Dec 07 2007 Oden Eriksson <oeriksson@mandriva.com> 1:2.10.5-3mdv2008.1
+ Revision: 116227
- fix deps

* Thu Dec 06 2007 David Walluck <walluck@mandriva.org> 1:2.10.5-2mdv2008.1
+ Revision: 116014
- readd old sources
- reintroduce version 2 as main package and bump epoch

* Mon Nov 26 2007 David Walluck <walluck@mandriva.org> 3.0.0-2mdv2008.1
+ Revision: 111999
- rename initscript to something more sensible

* Sun Nov 25 2007 David Walluck <walluck@mandriva.org> 3.0.0-1mdv2008.1
+ Revision: 111968
- add new sources
- 3.0.0
- new lib policy

* Fri Oct 26 2007 Jérôme Soyer <saispo@mandriva.org> 2.10.5-1mdv2008.1
+ Revision: 102337
- New release

* Tue Sep 11 2007 Anssi Hannula <anssi@mandriva.org> 2.10.4-2mdv2008.0
+ Revision: 84564
- enable initscript by default, it detects whether the modules are
  configured or not

* Fri Jul 20 2007 David Walluck <walluck@mandriva.org> 2.10.4-1mdv2008.0
+ Revision: 54003
- 2.10.4
- version Obsoletes and Provides
- only define DESTDIR during %%install
- reorder %%clean before post scripts
- no default runlevel in init script (needs configuring first)

* Fri Jun 01 2007 Christiaan Welvaart <spturtle@mandriva.org> 2.10.3-2mdv2008.0
+ Revision: 33655
- drop version from kernel-source build dependency since provides are not versioned


* Tue Mar 27 2007 David Walluck <walluck@mandriva.org> 2.10.3-1mdv2007.1
+ Revision: 149026
- 2.10.3

* Tue Jan 16 2007 David Walluck <walluck@mandriva.org> 2.10.2-1mdv2007.1
+ Revision: 109617
- 2.10.2

  + Emmanuel Andry <eandry@mandriva.org>
    - rebuild

* Thu Dec 14 2006 Emmanuel Andry <eandry@mandriva.org> 2.10.1-1mdv2007.1
+ Revision: 96582
- New version 2.10.1
  now relies on 2.6 kernel
  bunzip patches
  drop patches 0,2,3,4
- Import lm_sensors

* Tue May 23 2006 David Walluck <walluck@mandriva.org> 2.10.0-5mdk
- update patch for abituguru-1.1.7

* Wed Mar 15 2006 David Walluck <walluck@mandriva.org> 2.10.0-4mdk
- apply patch from CVS needed by uguru

* Wed Mar 15 2006 David Walluck <walluck@mandriva.org> 2.10.0-3mdk
- reapply uguru patch directly from author

* Mon Feb 20 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.10.0-2mdk
- add BuildRequires: libsysfs-devel

* Sun Feb 19 2006 David Walluck <walluck@mandriva.org> 2.10.0-1mdk
- 2.10.0
- rediff uguru patch

* Sun Jan 15 2006 David Walluck <walluck@mandriva.org> 2.9.2-1mdk
- 2.9.2
- rediff can-2005-2672 patch (mostly merged upstream)

* Mon Jan 09 2006 Olivier Blin <oblin@mandriva.com> 2.9.1-9mdk
- convert parallel init to LSB

* Tue Jan 03 2006 Couriousous <couriousous@mandriva.org> 2.9.1-8mdk
- Move lm_sensors startup after syslog ( take fedora startup number )

* Mon Jan 02 2006 David Walluck <walluck@mandriva.org> 2.9.1-7mdk
- add Abit uguru patch (1.1.1)
- bzip2 patches
- add provides %%{_lib}%%{name}-devel

* Sun Jan 01 2006 Couriousous <couriousous@mandriva.org> 2.9.1-6mdk
- Add parallel init stuff

* Fri Dec 23 2005 Oden Eriksson <oeriksson@mandriva.com> 2.9.1-5mdk
- added P1 to remove a faulty error message
- rpmlint fixes

* Sun Aug 28 2005 Emmanuel Blindauer <blindauer@mandriva.org> 2.9.1-4mdk
- P2: security fix for CAN-2005-2672 (Vincent Danen)

* Sat May 21 2005 sebastien Savarin <plouf@mandriva.org> 2.9.1-3mdk
- Add sensors-detect.patch.tar.bz2

* Sat May 21 2005 Stefan van der Eijk <stefan@eijk.nu> 2.9.1-2mdk
- %%mkrel
- rebuild for new rrd

* Sun May 01 2005 Emmanuel Blindauer <blindauer@mandriva.org> 2.9.1-1mdk
- New release 2.9.1
- ddcmon added
- Removed patch1 for udev (fixed upstream)

* Fri Feb 11 2005 Emmanuel Blindauer <mdk@agat.net> 2.9.0-4mdk
- Really fix the udev problem ( #10535, #13517)
- Add README.urpmi

* Thu Feb 10 2005 Emmanuel Blindauer <mdk@agat.net> 2.9.0-3mdk
- switch to sensors-detect provided by the lm_sensors team.

* Thu Jan 06 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.9.0-2mdk
- fix build on ppc (no isa tools)

* Fri Dec 31 2004 Emmanuel Blindauer <mdk@agat.net> 2.9.0-1mdk
- 2.9.0 
- happy new year

* Fri Oct 08 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.8.7-7mdk
- fix deps

* Tue Sep 28 2004 Emmanuel Blindauer <mdk@agat.net> 2.8.7-6mdk
- My fault, don't put bz2 in /usr/sbin (and don't build rpm when tired)

* Mon Sep 27 2004 Emmanuel Blindauer <mooby@agat.net> 2.8.7-5mdk
- Removed patch4 and added new source for sensors-detect udev-compatible

* Sat Jun 19 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.8.7-4mdk
- fix ppc build

* Fri Jun 18 2004 Blindauer Emmanuel <mooby@agat.net> 2.8.7-3mdk
- requires the correct name

* Thu Jun 17 2004 Blindauer Emmanuel <mooby@agat.net> 2.8.7-2mdk
- added requires against liblm_sensors

* Wed Jun 16 2004 Blindauer Emmanuel <mooby@agat.net> 2.8.7-1mdk
- 2.8.7
- Removed patch5 (kernel and lm_sensors in sync)

* Wed Apr 21 2004 Luca Berra <bluca@vodka.it> 2.8.6-2mdk 
- added *ugly* patch for compatibility with previous 2.6 kernels

* Wed Apr 21 2004 Luca Berra <bluca@vodka.it> 2.8.6-1mdk 
- 2.8.6 needed for 2.6.5 kernel
- removed p3 (merged upstream)
- rediffed p4

